ZL_CCtx_addHeaderComment

Function ZL_CCtx_addHeaderComment 

pub unsafe extern "C" fn ZL_CCtx_addHeaderComment(
    cctx: *mut ZL_CCtx,
    comment: *const c_void,
    commentSize: usize,
) -> ZL_Report
Adds header comment to the compressed frame for the following compression. The message will be overridden if added a second time. The message is erased from the cctx at the end of each compression.

@note A comment of size 0 clears the comment field.

@param comment The comment to add. The comment is copied and stored in the cctx. @param commentSize The size of the comment or 0 to clear the comment.