#[repr(C)]pub struct ZL_NodeParameters {
pub name: *const c_char,
pub localParams: *const ZL_LocalParams,
pub dictID: ZL_DictID,
pub mparam: ZL_MParam,
}Expand description
@defgroup Group_Compressor_NodeCustomization Node Customization
Nodes can be customized to override their name and local parameters. This is an advanced use case, and mainly an implementation detail of nodes. Most nodes that accept parameters provide helper functions to correctly parameterize the node.
@{
Fields
name: *const c_charOptionally a new name, if NULL it is derived from the node’s name
localParams: *const ZL_LocalParamsOptionally the new local params, if NULL then the parameters are not updated.
dictID: ZL_DictIDOptionally, a new dict ID. If set to ZL_DICT_ID_NULL, then the dict ID is not updated.
mparam: ZL_MParamOptionally, a new MParam.