pub unsafe extern "C" fn ZL_Encoder_getMParam(
eictx: *const ZL_Encoder,
) -> *const c_voidExpand description
@returns The materialized MParam object associated with this node, if there is one. Otherwise NULL. MParams are compression-only resources that are not required at decompression time.