pub unsafe extern "C" fn ZL_Graph_getErrorContextString(
graph: *const ZL_Graph,
report: ZL_Report,
) -> *const c_charExpand description
Gets the error context for a given ZL_Report. This context is useful for debugging and for submitting bug reports to Zstrong developers.
@param report The report to get the error context for
@returns A verbose error string containing context about the error that occurred.
@note: This string is stored within the @p graph and may only be valid for the lifetime of the @p graph.