#[repr(C)]pub struct ZL_MIEncoderDesc {
pub gd: ZL_MIGraphDesc,
pub transform_f: ZL_MIEncoderFn,
pub localParams: ZL_LocalParams,
pub name: *const c_char,
pub trStateMgr: ZL_CodecStateManager,
pub opaque: ZL_OpaquePtr,
pub materializer: ZL_MaterializerDesc,
pub dictMat: ZL_MaterializerDesc2,
pub dictID: ZL_DictID,
pub mparamMat: ZL_MaterializerDesc2,
pub mparam: ZL_MParam,
}Fields
gd: ZL_MIGraphDesctransform_f: ZL_MIEncoderFnlocalParams: ZL_LocalParamsname: *const c_chartrStateMgr: ZL_CodecStateManageropaque: ZL_OpaquePtrOptionally an opaque pointer that can be queried with ZL_Encoder_getOpaquePtr(). OpenZL unconditionally takes ownership of this pointer, even if registration fails, and it lives for the lifetime of the compressor.
materializer: ZL_MaterializerDescOptional materializer descriptor for materialized local params. If both materializeFn and dematerializeFn are non-null, the materializer will be used to create materialized objects from local params.
dictMat: ZL_MaterializerDesc2Optional materializer descriptor for materialized dicts. If both materializeFn and dematerializeFn are non-null, the materializer will be used to create materialized objects. Create a node with materialization using ZL_Compressor_parameterizeNode().
dictID: ZL_DictIDOptional dictionary ID associated with this encoder. When set, identifies the dictionary that this encoder requires. A zero-initialized value (ZL_DICT_ID_NULL) means no dictionary is associated.
mparamMat: ZL_MaterializerDesc2Optional materializer for compression-only materialized parameters (MParams). If materializeFn is non-null, it will be called during compressor deserialization to create the materialized object from the serialized MParam blob. Unlike dicts, MParams are NOT required at decompression time.
mparam: ZL_MParamOptional MParam associated with this encoder. The provided content blob will be materialized as dictated by @p mparamMat . OpenZL will not take ownership of the content provided. The caller is free to free the buffer anytime after registering the MIEncoder with ZL_Compressor_registerMIEncoder().